NotiFireService class

Constructors

NotiFireService({required String deviceId, Dio? dio})

Properties

deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendBulkMessages({required String message, required List<String> numbers}) Future<MessageResponse>
Sends a bulk text message to multiple recipients.
sendContact({required String to, required String contactName, required String contactPhone}) Future<MessageResponse>
Sends a contact message.
sendGroupMessage({required String groupId, required String type, String? text, String? url, String? caption, bool? ptt, String? name, String? phoneNumber, double? latitude, double? longitude}) Future<MessageResponse>
Sends a message to a WhatsApp group.
sendLocation({required String to, required double latitude, required double longitude}) Future<MessageResponse>
Sends a location message.
sendMedia({required String to, required Uint8List bytes, required String fileName, String? caption, bool? isVoiceNote}) Future<MessageResponse>
Sends a media message using raw bytes (optimized for web and mobile).
sendMediaFromFile({required String to, required File file, String? caption, bool? isVoiceNote}) Future<MessageResponse>
Sends a media message from a File (wrapper for mobile platforms).
sendMediaUrl({required String to, required String type, required String mediaUrl, String? caption, bool? isVoiceNote, String? fileName}) Future<MessageResponse>
Sends a media message using a URL.
sendTextMessage({required String to, required String message}) Future<MessageResponse>
Sends a text message to a single recipient.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited